function fileList = generateEdgeFiles(rSize, numPerNoise, psfSize, psfSigma, angleRange, angleInc, shiftRange, shiftInc, noiseRange, noiseInc, darkVal, lightVal, outDir)

	if nargin < 11
		darkVal = 0;
	end

	if nargin < 12
		lightVal = 255;
	end

	if nargin < 13
		outDir = pwd;
	end

	fileList = {};

	psf = fspecial('gaussian', psfSize, psfSigma);

	baseImage = uint8(zeros(rSize)+darkVal);
	center = round(rSize/2);

	for i=angleRange(1):angleInc:angleRange(2)
		currentImage = baseImage;
		slope = tan( (i+90)*(pi/180) );

		for y=1:rSize(1)
			x = ((y-center(1))/slope)+center(2);
			if x < 1
				x = 1;
			elseif x > rSize(2)
				x = rSize(2);
			end
			xFrac = x-floor(x);
			x = floor(x);

			currentImage( y,1:x-1 ) = darkVal;
			currentImage( y,x+1:end ) = lightVal;

			currentImage( y,x ) = uint8( round( darkVal*xFrac+lightVal*(1-xFrac) ) );
		end

		currentImage = imfilter(currentImage, psf, 'replicate');

		fileList{end+1} = [outDir filesep sprintf('slant_ideal_angle%.2f_light%.0f_dark_%.0f.png',i,lightVal,darkVal)];
		imwrite(currentImage,fileList{end},'png');

		for j=shiftRange(1):shiftInc:shiftRange(2)
			shiftImage = baseImage;
			for y=1:rSize(1)
				x = ((y-center(1))/slope)+center(2)-j;
				if x < 1
					x = 1;
				elseif x > rSize(2)
					x = rSize(2);
				end
				xFrac = x-floor(x);
				x = floor(x);

				shiftImage( y,1:x-1 ) = darkVal;
				shiftImage( y,x+1:end ) = lightVal;

				shiftImage( y,x ) = uint8( round( darkVal*xFrac+lightVal*(1-xFrac) ) );
			end

			shiftImage = imfilter(shiftImage, psf, 'replicate');

			fileList{end+1} = [outDir filesep sprintf('slant_angle%.2f_shift%.0f_light%.0f_dark_%.0f.png',i,j,lightVal,darkVal)];
			imwrite(shiftImage,fileList{end},'png');
         k = noiseRange(1);
			while k < noiseRange(2)
				for l=1:numPerNoise
					noiseImage = imnoise(shiftImage,'gaussian',0,k);
					fileList{end+1} = [outDir filesep sprintf('slant_angle%.2f_noise%.6f_shift%.0f_light%.0f_dark_%.0f_%d.png',i,k,j,lightVal,darkVal,l)];
					imwrite(noiseImage,fileList{end},'png');
				end
            k = k*noiseInc;
			end
		end
	end

end